summaryrefslogtreecommitdiff
path: root/pthread_support.c
diff options
context:
space:
mode:
authorIvan Maidanski <ivmai@mail.ru>2022-10-16 11:10:24 +0300
committerIvan Maidanski <ivmai@mail.ru>2022-10-17 12:43:33 +0300
commit42d3dc7aae0eeea7f861497a0509b47970a1a363 (patch)
tree3cf8be8c04566d80e51978d16f48f70470ad0b74 /pthread_support.c
parent70fa0739e2b0e7791063fc6743e9e5aa98d02dad (diff)
downloadbdwgc-42d3dc7aae0eeea7f861497a0509b47970a1a363.tar.gz
Rename GC_[inner_]start_routine to match that for Win32
(refactoring) * include/private/pthread_support.h [!GC_WIN32_THREADS] (GC_inner_start_routine): Rename to GC_pthread_start_inner. * pthread_start.c (GC_inner_start_routine): Likewise. * pthread_start.c (__EXCEPTIONS): Update comment. * pthread_support.c (GC_start_rtn_prepare_thread): Likewise. * pthread_support.c (GC_start_rtn_prepare_thread): Call GC_pthread_start_inner instead of GC_inner_start_routine. * pthread_support.c [!SN_TARGET_ORBIS && !SN_TARGET_PSP2] (GC_start_routine): Rename to GC_pthread_start. * pthread_support.c [!SN_TARGET_ORBIS && !SN_TARGET_PSP2] (pthread_create): Call GC_pthread_start instead of GC_start_routine.
Diffstat (limited to 'pthread_support.c')
-rw-r--r--pthread_support.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/pthread_support.c b/pthread_support.c
index eb2cb658..fd14b1b0 100644
--- a/pthread_support.c
+++ b/pthread_support.c
@@ -2113,7 +2113,7 @@ struct start_info {
/* parent hasn't yet noticed. */
};
/* Called from GC_inner_start_routine(). Defined in this file to */
/* minimize the number of include files in pthread_start.c (because */
/* sem_t and sem_post() are not used that file directly). */
GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
@@ -2148,7 +2148,7 @@ GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
}
#if !defined(SN_TARGET_ORBIS) && !defined(SN_TARGET_PSP2)
- STATIC void * GC_start_routine(void * arg)
+ STATIC void * GC_pthread_start(void * arg)
{
# ifdef INCLUDE_LINUX_THREAD_DESCR
struct GC_stack_base sb;
@@ -2165,9 +2165,9 @@ GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
# ifdef REDIRECT_MALLOC
GC_enable();
# endif
- return GC_inner_start_routine(&sb, arg);
+ return GC_pthread_start_inner(&sb, arg);
# else
- return GC_call_with_stack_base(GC_inner_start_routine, arg);
+ return GC_call_with_stack_base(GC_pthread_start_inner, arg);
# endif
}
@@ -2242,8 +2242,8 @@ GC_INNER_PTHRSTART GC_thread GC_start_rtn_prepare_thread(
GC_start_mark_threads();
# endif
set_need_to_lock();
- result = REAL_FUNC(pthread_create)(new_thread, attr, GC_start_routine,
- &si);
+ result = REAL_FUNC(pthread_create)(new_thread, attr,
+ GC_pthread_start, &si);
/* Wait until child has been added to the thread table. */
/* This also ensures that we hold onto the stack-allocated si until */
@@ -2113,7 +2113,7 @@ struct start_info {
/* parent hasn't yet noticed. */
};
-/* Called from GC_inner_start_routine(). Defined in this file to */
+/* Called from GC_pthread_start_inner(). Defined in this file to */
/* minimize the number of include files in pthread_start.c (because */
/* sem_t and sem_post() are not used that file directly). */